==> 0.10.3.tar.gz: vscode/src/vs/platform/contextview/browser/contextView.ts <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';

import Lifecycle = require('vs/base/common/lifecycle');
import Actions = require('vs/base/common/actions');
import ActionBar = require('vs/base/browser/ui/actionbar/actionbar');
import winjs = require('vs/base/common/winjs.base');
import {Keybinding} from 'vs/base/common/keyCodes';
import {createDecorator, ServiceIdentifier} from 'vs/platform/instantiation/common/instantiation';

export var IContextViewService = createDecorator<IContextViewService>('contextViewService');

export interface IContextViewService {
	serviceId : ServiceIdentifier<any>;
	showContextView(delegate: IContextViewDelegate):void;
	hideContextView(data?: any):void;
	layout():void;
}

export interface IContextViewDelegate {
	getAnchor():HTMLElement|{x: number; y: number; }
	render(container: HTMLElement): Lifecycle.IDisposable;
	canRelayout?:boolean; // Default: true
	onDOMEvent?(e:Event, activeElement: HTMLElement):void;
	onHide?(data?: any):void;
}

export var IContextMenuService = createDecorator<IContextMenuService>('contextMenuService');

export interface IContextMenuService {
	serviceId : ServiceIdentifier<any>;
	showContextMenu(delegate: IContextMenuDelegate):void;
}

export interface IContextMenuDelegate {
	getAnchor():HTMLElement|{x: number; y: number; }
	getActions(): winjs.Promise;
	getActionItem?(action: Actions.IAction): ActionBar.IActionItem;
	getActionsContext?():any;
	getKeyBinding?(action: Actions.IAction): Keybinding;
	getMenuClassName?():string;
	onHide?(didCancel: boolean): void;
}

==> 0.10.8.tar.gz: vscode/src/vs/platform/contextview/browser/contextView.ts <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';

import Lifecycle = require('vs/base/common/lifecycle');
import { IAction } from 'vs/base/common/actions';
import ActionBar = require('vs/base/browser/ui/actionbar/actionbar');
import { TPromise } from 'vs/base/common/winjs.base';
import {Keybinding} from 'vs/base/common/keyCodes';
import {createDecorator, ServiceIdentifier} from 'vs/platform/instantiation/common/instantiation';

export var IContextViewService = createDecorator<IContextViewService>('contextViewService');

export interface IContextViewService {
	serviceId : ServiceIdentifier<any>;
	showContextView(delegate: IContextViewDelegate):void;
	hideContextView(data?: any):void;
	layout():void;
}

export interface IContextViewDelegate {
	getAnchor():HTMLElement|{x: number; y: number; }
	render(container: HTMLElement): Lifecycle.IDisposable;
	canRelayout?:boolean; // Default: true
	onDOMEvent?(e:Event, activeElement: HTMLElement):void;
	onHide?(data?: any):void;
}

export var IContextMenuService = createDecorator<IContextMenuService>('contextMenuService');

export interface IContextMenuService {
	serviceId : ServiceIdentifier<any>;
	showContextMenu(delegate: IContextMenuDelegate):void;
}

export interface IContextMenuDelegate {
	getAnchor():HTMLElement|{x: number; y: number; }
	getActions(): TPromise<IAction[]>;
	getActionItem?(action: IAction): ActionBar.IActionItem;
	getActionsContext?():any;
	getKeyBinding?(action: IAction): Keybinding;
	getMenuClassName?():string;
	onHide?(didCancel: boolean): void;
}
